@@ -21,6 +21,11 @@ class AddonCli:
         pass
 
     def main(self, arguments):
+        """
+        Main entry point for the addon management
+
+        :param arguments: The command line arguments
+        """
         parser = argparse.ArgumentParser(
             prog="scistag",
             description="Installs or removes an optional add-on",
@@ -38,7 +43,8 @@ class AddonCli:
     Example:
     python3 -m scistag.addons install emojis.svg
     
-    """)
+    """,
+        )
         parser.add_argument("command", choices=["install", "remove"])
         params = parser.parse_args(arguments[:1])
         command = params.command
@@ -56,7 +62,8 @@ class AddonCli:
         for key, addon in all_addons.items():
             result.append(
                 f"* {key} - {addon[FEATURE_INFO]} "
-                f"({addon[FEATURE_SIZE] / 2 ** 20:0.1f} MB)")
+                f"({addon[FEATURE_SIZE] / 2 ** 20:0.1f} MB)"
+            )
         return "\n".join(result)
 
     @staticmethod
@@ -72,7 +79,8 @@ class AddonCli:
                 continue
             result.append(
                 f"* {key} - {addon[FEATURE_INFO]} "
-                f"({addon[FEATURE_SIZE] / 2 ** 20:0.1f} MB)")
+                f"({addon[FEATURE_SIZE] / 2 ** 20:0.1f} MB)"
+            )
         return "\n".join(result)
 
     @classmethod
@@ -108,9 +116,9 @@ class AddonCli:
 
 List of available addons:
 {cls.get_all_addons()}
-        """)
-        parser.add_argument("addons",
-                            choices=AddonManager.get_all_addons().keys())
+        """,
+        )
+        parser.add_argument("addons", choices=AddonManager.get_all_addons().keys())
         params = parser.parse_args(arguments)
         addons = cls.validate_addons(params.addons)
         if len(addons) == 0:
@@ -134,9 +142,11 @@ List of available addons:
 
 List of installed addons:
 {cls.get_installed_addons()}
-        """)
-        parser.add_argument("addons",
-                            choices=AddonManager.get_installed_addons().keys())
+        """,
+        )
+        parser.add_argument(
+            "addons", choices=AddonManager.get_installed_addons().keys()
+        )
         params = parser.parse_args(arguments)
         addons = cls.validate_addons(params.addons)
         if len(addons) == 0:
@@ -146,6 +156,6 @@ List of installed addons:
             AddonManager.remove_addon(element)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     addon_cli = AddonCli()
     addon_cli.main(sys.argv[1:])
