@@ -6,11 +6,14 @@ from __future__ import annotations
 
 import hashlib
 import time
+from fnmatch import fnmatch
 
 from typing import Any, Callable
 
 from scistag.common.mt.stag_lock import StagLock
 
+DISK_CACHE_HEADER = "$"
+
 
 class Cache:
     """
@@ -50,7 +53,7 @@ class Cache:
         # caching on disk between execution runs
         # if you run the cache "manually" you have to set a version number to
         # cache data between multiple execution sessions on disk.
-        my_data = my_cache.cache("./data@5", complex_computation)
+        my_data = my_cache.cache("$data@5", complex_computation)
 
     If you pass a version of 0 the :meth:`get_app_session_id` will
     be used instead which will usually change on every restart except
@@ -66,7 +69,7 @@ class Cache:
     between application restarts.
     """
 
-    def __init__(self, version: int = 1, cache_dir: str = None):
+    def __init__(self, version: str | int = 1, cache_dir: str = None):
         """
         :param version: The cache version. 1 by default.
 
@@ -87,11 +90,9 @@ class Cache:
         """
         self._mem_cache_versions = {}
         "Version numbers for the elements stored in the memory cache"
-        self._mem_cache_params = {}
-        "Parameters for the elements stored in the memory cache"
         from scistag.common.disk_cache import DiskCache
-        self._disk_cache = DiskCache(version=version,
-                                     cache_dir=cache_dir)
+
+        self._disk_cache = DiskCache(version=version, cache_dir=cache_dir)
         "Cache for persisting data between execution sessions"
         self._version = version
         """
@@ -131,13 +132,17 @@ class Cache:
         :meth:`add_volatile_member` which do not get removed but automatically 
         cleared upon execution of unload. 
         """
+        self._key_revisions = {}
+        """
+        Version counter for each key
+        """
 
     @property
-    def version(self) -> int:
+    def version(self) -> str:
         """
         Returns the cache version
         """
-        return self._version
+        return str(self._version)
 
     @classmethod
     def get_app_session_id(cls) -> int:
@@ -187,7 +192,7 @@ class Cache:
                 for live-editing).
         """
         if minor is None:
-            minor = 1 if "/" in key else 0
+            minor = 1 if DISK_CACHE_HEADER in key else 0
         if "@" in key:
             split_val = key.split("@")
             assert len(split_val) == 2
@@ -200,11 +205,7 @@ class Cache:
             return key, f"{minor}"
         return key, f"{major}.{minor}"
 
-    def cache(self,
-              key: str,
-              generator: Callable,
-              *args,
-              **kwargs):
+    def cache(self, key: str, generator: Callable, *args, **kwargs):
         """
         Tries to find the element **key** in the cache and return's it's
         content. If no element with such a name and/or version number can be
@@ -232,35 +233,20 @@ class Cache:
         version = kwargs.pop("version", None)
         if hash_val is not None:
             version = str(version) if version else "0"
-            from scistag.filestag import Bundle
-            hash_data = Bundle.bundle(hash_val, compression=0)
-            version += "." + hashlib.md5(hash_data).hexdigest()
+            version += "#" + hash_val
         arg_list = list(args)
-        param_list = []
-        # build effective argument and keyword argument lists
-        params = {}
-        if len(kwargs):  # store key words in params
-            for ele_key, item in kwargs.items():
-                params[ele_key] = item
-        func_params = dict(params)
-        for index, element in enumerate(param_list):
-            params[f"_arg{index + len(param_list)}"] = element
-            arg_list.append(element)
-        if len(args) > 0:  # attach arguments to parameter set if provided
-            for index, element in enumerate(args):
-                params[f"_arg{index + len(param_list)}"] = element
         # try to fetch from cache
         with self._access_lock:
-            old_value = self.get(key, version=version, params=params)
+            old_value = self.get(key, version=version)
             if old_value is not None:  # cached? fine
                 return old_value
-        new_data = generator(*arg_list, **func_params)
+        new_data = generator(*arg_list, **kwargs)
         # update cache otherwise
         with self._access_lock:
-            self.set(key, new_data, params, version=version)
+            self.set(key, new_data, version=version)
             return new_data
 
-    def set(self, key: str, value, params: dict | None = None, version=None):
+    def set(self, key: str, value, version=None) -> Any:
         """
         Adds an item to the cache or updates it.
 
@@ -271,39 +257,38 @@ class Cache:
 
         :param key: The item's name
         :param value: The value to assign
-        :param params: The parameters associated with the creation of value
-            and to be stored (and verified) in combination with the version.
         :param version: The version of the cache element. By default 0 for
             memory cache elements and 1 for disk cache elements.
+        :return: The assigned value
+
         """
         with self._access_lock:
             org_key = key
-            key, eff_version = self.get_key_and_version(key,
-                                                        self._version,
-                                                        minor=version)
+            key, eff_version = self.get_key_and_version(
+                key, self._version, minor=version
+            )
             assert len(key) > 0
-            if params is None:
-                params = {}
-            if not key[0].isalpha() and not key.startswith(
-                    "./") and not key.startswith("_"):
+            if (
+                not key[0].isalpha()
+                and not key.startswith(DISK_CACHE_HEADER)
+                and not key.startswith("_")
+            ):
                 raise ValueError("Keys has to start with a character")
-            if "/" in key:
-                self._disk_cache.set(org_key, value, params=params,
-                                     version=version)
-                return
+            if key in self._key_revisions:
+                self._key_revisions[key] += 1
+            else:
+                self._key_revisions[key] = 1
+            if key.startswith(DISK_CACHE_HEADER):
+                self._disk_cache.set(org_key, value, version=version)
+                return value
             # flag of volatile if added during loading process
             if key not in self._mem_cache and self._is_loading:
                 self._volatile_cache_entries.add(key)
             self._mem_cache[key] = value
             self._mem_cache_versions[key] = eff_version
-            self._mem_cache_params[key] = params
+            return value
 
-    def get(self,
-            key: str,
-            default=None,
-            version=None,
-            params: dict | None = None,
-            hash_params=False):
+    def get(self, key: str, default=None, version=None):
         """
         Returns a value from the cache.
 
@@ -314,10 +299,6 @@ class Cache:
 
             By default 0 for memory cache elements and 1 for disk cache
             elements.
-        :param params: The parameters which were passed into the function
-            and still need t match.
-        :param hash_params: Defines the parameters shall be hashed to
-            detect modifications.
         :param default: The value to return by default if no cache element
             could be found.
         :return: The item's value.
@@ -325,26 +306,42 @@ class Cache:
         Returns default if no value can be found.
         """
         with self._access_lock:
-            if params is None:
-                params = {}
             org_key = key
-            key, eff_version = self.get_key_and_version(key, self._version,
-                                                        minor=version)
-            if "/" in key:
-                data = self._disk_cache.get(org_key,
-                                            params=params,
-                                            hash_params=hash_params,
-                                            version=version)
+            key, eff_version = self.get_key_and_version(
+                key, self._version, minor=version
+            )
+            if key.startswith(DISK_CACHE_HEADER):
+                data = self._disk_cache.get(org_key, version=version)
                 if data is None:
                     return default
                 return data
-            if (key in self._mem_cache and
-                    self._mem_cache_versions[key] == eff_version and
-                    (not hash_params or self._mem_cache_params[key] == params)):
+            if key in self._mem_cache and self._mem_cache_versions[key] == eff_version:
                 return self._mem_cache[key]
             else:
                 return default
 
+    def get_revision(self, key) -> int:
+        """
+        Returns the revision of given cache entry.
+
+        If the value does not exist yet it has a revision of 0 by default.
+
+        :param key: The key of the version to return
+        :return: The revision. 0 if the key does not exist.
+        """
+        with self._access_lock:
+            return self._key_revisions.get(key, 0)
+
+    def clear(self):
+        """
+        Clears the disk cache completely
+
+        """
+        with self._access_lock:
+            self._mem_cache = {}
+            self._mem_cache_versions = {}
+        self._disk_cache.clear()
+
     def load(self):
         """
         Call this before you start using a component for the first time. The
@@ -359,32 +356,35 @@ class Cache:
             if not self.loaded:
                 raise RuntimeError(
                     "loaded flag of component not correctly set to True. "
-                    "Did you forget to call super().handle_load()?")
+                    "Did you forget to call super().handle_load()?"
+                )
 
     def unload(self):
         """
         Call this to unload all data from your component which was created
-        during the handle_load execution and not flagged via a slash ("/")
+        during the handle_load execution and not flagged via a $
         in its name as element to cache on disk.
         """
         with self._access_lock:
             if not self.loaded:
                 raise RuntimeError(
-                    "Tried to unload component which was not loaded before")
+                    "Tried to unload component which was not loaded before"
+                )
             self.handle_unload()
             if self.loaded:
                 raise RuntimeError(
                     "loaded flag of component not correctly set to False. "
-                    "Did you forget to call super().handle_unload()?")
+                    "Did you forget to call super().handle_unload()?"
+                )
             for element in self._volatile_cache_entries:
-                element: str
                 if element.startswith("."):  # clear volatile members
                     member_name = element[1:]
-                    if member_name in self.__dict__:
-                        self.__dict__[member_name] = None
+                    self.__dict__[member_name] = None
                 # delete volatile cache entries
                 elif element in self._mem_cache:
                     del self._mem_cache[element]
+                    del self._mem_cache_versions[element]
+                    self._key_revisions[element] += 1
 
     def get_is_loading(self) -> bool:
         """
@@ -456,32 +456,233 @@ class Cache:
 
     def __setitem__(self, key: str, value):
         self.set(key, value)
+        return value
 
     def __getitem__(self, key) -> Any:
         with self._access_lock:
             result = self.get(key)
-            if (result is None and key not in self._mem_cache and key not in
-                    self._disk_cache):
+            if (
+                result is None
+                and key not in self._mem_cache
+                and key not in self._disk_cache
+            ):
                 raise KeyError(f"Key {key} not found")
             return result
 
+    def inc(self, key, value: float | int = 1) -> float | int:
+        """
+        Increases given cache value.
+
+        If the value does not exist yet, it will be created
+
+        :param key: The key to increase
+        :param value: The value by which the value shall be increased
+        :return: The new value
+        """
+        with self._access_lock:
+            if key in self:
+                new_value = self[key] + value
+                self[key] = new_value
+                return new_value
+            else:
+                self[key] = value
+                return value
+
+    def dec(self, key, value: float | int) -> float | int:
+        """
+        Decreases given cache value.
+
+        If the value does not exist yet, it will be created
+
+        :param key: The key to increase
+        :param value: The value by which the value shall be decreased
+        :return: The new value
+        """
+        with self._access_lock:
+            if key in self:
+                new_value = self[key] - value
+                self[key] = new_value
+                return new_value
+            else:
+                self[key] = -value
+                return -value
+
+    def lpush(self, key: str, *args, unpack: bool = False):
+        """
+        Appends the value provided to the list named key.
+
+        If the list does not exist yet it will be created
+
+        :param key: The key of the list
+        :param args: The value or values to be added
+        :param unpack: Defines if value is a list and all of its elements shall be
+            added to the target list
+        """
+        if len(args) == 1:
+            value = args[0]
+        else:
+            value = list(args)
+            unpack = True
+        with self._access_lock:
+            if key in self:
+                tar_list = self[key]
+                self.increase_revision(key, True)
+            else:
+                tar_list = []
+                self[key] = tar_list
+            if not isinstance(tar_list, list):
+                raise ValueError(
+                    f"Tried to append new values to non-list " f"element {key}"
+                )
+            if unpack:
+                if not isinstance(value, list):
+                    raise ValueError("Can only unpack lists")
+                tar_list.extend(value)
+            else:
+                tar_list.append(value)
+
+    def lpop(self, key: str, index: int = 0, count: int = 1):
+        """
+        Pops one or multiple values from the list
+
+        :param key: The key of the list
+        :param index: The index from which the value shall be received.
+
+            At the moment only 0 (from list front) and -1 (from end) are supported.
+        :param count: The count of values to pop.
+
+            If a count of -1 is passed all values will be received.
+        :return: A list of all values received.
+
+            An empty list if the list does not exist
+        """
+        if count == 0:
+            return []
+        if count < 0:
+            raise ValueError("Passed negative count argument")
+        with self._access_lock:
+            if key not in self:
+                return []
+            src_list = self[key]
+            if not isinstance(src_list, list):
+                raise ValueError(f"Tried to pop values from non-list element {key}")
+            if count >= len(src_list) or count == -1:
+                results = src_list
+                self[key] = []
+            else:
+                if index == -count:
+                    results = src_list[-count:]
+                    end = len(src_list) - count
+                    self[key] = src_list[0:end]
+                elif index == 0:
+                    results = src_list[0:count]
+                    self[key] = src_list[count:]
+                else:
+                    raise ValueError(
+                        f"Indices other than 0 and -count currently not supported"
+                    )
+            return results
+
+    def llen(self, key: str) -> int:
+        """
+        Receives the length of the list with given name
+
+        :param key: The list's name in the cache
+        :return: The list's length if the list is known, 0 otherwise.
+        """
+        with self._access_lock:
+            if key not in self:
+                return 0
+            src_list = self[key]
+            if not isinstance(src_list, list):
+                raise ValueError(f"Tried to receive length of non-list element {key}")
+            return len(src_list)
+
+    def increase_revision(self, key, _already_locked=False):
+        """
+        Increases the version of given key
+
+        :param key: The key to modify
+        :param _already_locked: Defines if we are already locked
+        :return: The new version
+        """
+        if _already_locked:
+            self._key_revisions[key] += 1
+            return self._key_revisions[key]
+        else:
+            with self._access_lock:
+                self._key_revisions[key] += 1
+                return self._key_revisions[key]
+
+    def remove(self, keys: str | list[str]) -> int:
+        """
+        Removes the key or keys matching the name or the name mask provided.
+
+        You can use * and ? to remove a set of cache entries in one go.
+
+        In difference to a del cache["keyName"] the remove method fails silently
+        and though can be used pretty well to do a "cleanup" w/o additional check
+        for existence.
+
+        :param keys: A single name or a list of names of keys to remove.
+
+            Can contain placeholders such as * and ?
+        :return: The number of elements deleted
+        """
+        with self._access_lock:
+            if isinstance(keys, str):
+                keys = [keys]
+            remove_set = set()
+            for element in keys:
+                if "?" in element or "*" in element:
+                    for cur_key in self._key_revisions.keys():
+                        if fnmatch(cur_key, element):
+                            remove_set.add(cur_key)
+                else:
+                    if element in self._key_revisions:
+                        remove_set.add(element)
+            for element in remove_set:
+                if element in self:
+                    del self[element]
+
+            return len(remove_set)
+
+    def non_zero(self, key: str) -> bool:
+        """
+        Returns if the element has a non-zero size
+
+        :param key: The key of the element to check
+        :return True: If the element does exist and has a size or length > 0
+        """
+        with self._access_lock:
+            if key not in self:
+                return False
+            element = self[key]
+            if isinstance(element, (float, bool, int)):
+                return element != 0
+            if isinstance(element, (str, dict, list, bytes, tuple)):
+                return len(element) > 0
+            if hasattr(element, "shape"):  # np.ndarray and DataFrame
+                return element.shape[0] > 0
+            return False
+
     def __delitem__(self, key):
         """
         Deletes an element from the cache.
 
-        If the element does not exist a ValueError exception will be raised.
+        Does raise a value error if the key does not exist yet.
 
         :param key: The element's name
         """
         with self._access_lock:
             key, eff_version = self.get_key_and_version(key, self._version)
-            if "/" in key:
+            if key.startswith(DISK_CACHE_HEADER):
                 self._disk_cache.delete(key)
+                return
             if key not in self._mem_cache:
-                raise KeyError(f"The value {key} is not defined in the cache")
+                raise KeyError("Key not found")
             del self._mem_cache[key]
-            del self._mem_cache_versions[key]
-            del self._mem_cache_params[key]
+            self._key_revisions[key] += 1
 
     def __contains__(self, key) -> bool:
         """
@@ -492,7 +693,28 @@ class Cache:
         """
         with self._access_lock:
             key, eff_version = self.get_key_and_version(key, self._version)
-            if "/" in key:
+            if key.startswith(DISK_CACHE_HEADER):
                 return key in self._disk_cache
-            return (key in self._mem_cache and
-                    self._mem_cache_versions[key] == eff_version)
+            return (
+                key in self._mem_cache and self._mem_cache_versions[key] == eff_version
+            )
+
+
+_cache_access_lock = StagLock()
+"Cache creation lock"
+_global_cache: Cache | None = None
+"Shared, singleton global cache"
+
+
+def get_global_cache() -> Cache:
+    """
+    Returns the shared global cache class. When storing data categorize it
+    w/ a main module and sub module to track memory usage of the shared cache.
+
+    :return: The global cache
+    """
+    global _global_cache
+    with _cache_access_lock:
+        if _global_cache is None:
+            _global_cache = Cache()
+        return _global_cache
