@@ -1,3 +1,8 @@
+"""
+Implements the class :class:`RemoteFunction` which defines a function which
+can execute work load in the background and asynchronously.
+"""
+
 from __future__ import annotations
 import abc
 
@@ -25,8 +30,7 @@ class RemoteFunction:
         self.full_identifier = f"{service_identifier}.{function_name}"
         self.service.register_function(self)
 
-    def wrap(self,
-             result_value: str | int | bool | float | bytes | np.ndarray):
+    def wrap(self, result_value: str | int | bool | float | bytes | np.ndarray):
         """
         Returns a dictionary wrapping a single result value
         :param result_value: The simple result value
@@ -34,8 +38,9 @@ class RemoteFunction:
         """
         return {self.RESULT_VALUE: result_value}
 
-    def unwrap(self, input_dict: dict) -> \
-        str | int | bool | float | bytes | np.ndarray | dict:
+    def unwrap(
+        self, input_dict: dict
+    ) -> str | int | bool | float | bytes | np.ndarray | dict:
         """
         Returns a dictionary wrapping a single result value
         :param input_dict: A dictionary
