@@ -8,5 +8,5 @@ def make_uncacheable(r):
         r.headers["Cache-Control"] = "no-cache, no-store, must-revalidate"
         r.headers["Pragma"] = "no-cache"
         r.headers["Expires"] = "0"
-        r.headers['Cache-Control'] = 'public, max-age=0'
+        r.headers["Cache-Control"] = "public, max-age=0"
     return r
